@@ -6,7 +6,7 @@ import argparse
 import sounddevice as sd
 from vosk import Model, KaldiRecognizer
 import json
-from googletrans import Translator
+from pygoogletranslation import Translator
 import PySimpleGUI as sg
 try:
     import queue  # Python 3 import
@@ -450,7 +450,7 @@ def translate(phrase, src, dest):
 def timed_translate(src, dst):
     global main_window
 
-    WAIT_SECONDS=0.2
+    WAIT_SECONDS=0.15
     phrase = str(main_window['-ML1-'].get())
     if (len(phrase)>0):
         translated_text = translate(phrase, src, dst)
